/**
 * BLE discovery wrappers for finding HAP devices.
 */
/// <reference types="node" />
import { EventEmitter } from 'events';
import noble from '@abandonware/noble';
export interface HapService {
    name: string;
    CoID: number;
    TY: number;
    AIL: number;
    SF: number;
    DeviceID: string;
    ACID: number;
    GSN: number;
    CN: number;
    CV: number;
    peripheral: noble.Peripheral;
}
export default class BLEDiscovery extends EventEmitter {
    private scanEnabled;
    private allowDuplicates;
    private services;
    private handleStateChange;
    private handleDiscover;
    private handleScanStart;
    private handleScanStop;
    constructor();
    /**
     * Start searching for BLE HAP devices.
     *
     * @param {boolean} allowDuplicates - Allow duplicate serviceUp events. This
     *                  is needed for disconnected events, where the GSN is
     *                  updated in the advertisement.
     */
    start(allowDuplicates?: boolean): void;
    /**
     * List the currently known services.
     *
     * @returns {Object[]} Array of services
     */
    list(): HapService[];
    /**
     * Stop an ongoing discovery process.
     */
    stop(): void;
    private _handleStateChange;
    private _handleScanStart;
    private _handleScanStop;
    private _handleDiscover;
}
//# sourceMappingURL=ble-discovery.d.ts.map